@@ -4,8 +4,19 @@ use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '0.03'; # VERSION
-our $DATE = '2014-06-26'; # DATE
+our $VERSION = '0.04'; # VERSION
+our $DATE = '2014-06-27'; # DATE
+
+our $_complete_program = sub {
+    require Complete::Util;
+    my %args = @_;
+    Complete::Util::mimic_shell_dir_completion(
+        completion => Complete::Util::complete_program(
+            word      => $args{word},
+            ci        => 1,
+        )
+    );
+};
 
 1;
 # ABSTRACT: Command line to manipulate programs in PATH
@@ -22,7 +33,7 @@ App::ProgUtils - Command line to manipulate programs in PATH
 
 =head1 VERSION
 
-This document describes version 0.03 of App::ProgUtils (from Perl distribution App-ProgUtils), released on 2014-06-26.
+This document describes version 0.04 of App::ProgUtils (from Perl distribution App-ProgUtils), released on 2014-06-27.
 
 =head1 SYNOPSIS
 
